## 基金规模数据

接口：fund_share，可以通过数据工具调试和查看数据。

描述：获取基金规模数据，包含上海和深圳ETF基金

限量：单次最大提取2000行数据

积分：用户需要至少2000积分可以调取，5000积分以上频次较高，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS基金代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| market | str | N | 市场代码（SH上交所 ，SZ深交所） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 基金代码，支持多只基金同时提取，用逗号分隔 |
| trade_date | str | Y | 交易（变动）日期，格式YYYYMMDD |
| fd_share | float | Y | 基金份额（万） |

代码示例

```python
#初始接口
pro = ts.pro_api()

#单只基金
df = pro.fund_share(ts_code='150018.SZ')

#多只基金
df = pro.fund_share(ts_code='150018.SZ,150008.SZ')
```

数据示例

```python
ts_code trade_date  fd_share
0     150018.SZ   20200214  206733.2898
```